from OBP_reliability_pillar.lambdafn.lambda_dlq_check import *
import logging

from OBP_reliability_pillar.lambdafn.lambda_inside_vpc import lambda_inside_vpc

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger()


# checks aws lambda compliance
def lambda_compliance(self) -> dict:
    """
    :param self:
    :return:
    """
    logger.info(" ---Inside lambdafn :: lambda_compliance()")
    response = [
        lambda_dlq_check(self),
        lambda_inside_vpc(self),
    ]

    return response